################################################################################################################################
#
# Description:	This constraint file applies to hardware features that are unique to a specific model number within a
#				product family.
#
# Rev History: 	07-14-2015:	Removed IDELAY group constraints that were required by the QDR MIG core that was removed.
# 				07-23-2014:	Inital release.
#
################################################################################################################################

###################################################### Timing Constraints ######################################################

# Set the RX1 clock frequency to 250 MHz
create_clock -period 4.000 -name rx_clk [get_ports sample_clk_p]
set_clock_groups -name async_rx_clk -asynchronous -group [get_clocks rx_clk]

# Set a false path to the clock input buffer used for dynamic phase alignment.
set_false_path -through [get_pins {XCVR/RX_CH.ADC/CLK_FORWARD[1].CLK_DDR/D}]

###################################################### Pinout Constraints ######################################################
# Note: The external component and pin name connected to each PACKAGE_PIN is shown as a comment (#component:pin).

# Sample clock generated by the frequency synthesizer.
set_property PACKAGE_PIN G22 [get_ports sample_clk_p];  #AD9512:CLKOUT0P

# RX1 pin assignments.
set_property PACKAGE_PIN N19 [get_ports {rx1_data_in_p[0]}];  #ADS42LB69:DA[0]P
set_property PACKAGE_PIN P19 [get_ports {rx1_data_in_p[1]}];  #ADS42LB69:DA[1]P
set_property PACKAGE_PIN M21 [get_ports {rx1_data_in_p[2]}];  #ADS42LB69:DA[2]P
set_property PACKAGE_PIN N21 [get_ports {rx1_data_in_p[3]}];  #ADS42LB69:DA[3]P
set_property PACKAGE_PIN M24 [get_ports {rx1_data_in_p[4]}];  #ADS42LB69:DA[4]P
set_property PACKAGE_PIN K25 [get_ports {rx1_data_in_p[5]}];  #ADS42LB69:DA[5]P
set_property PACKAGE_PIN M25 [get_ports {rx1_data_in_p[6]}];  #ADS42LB69:DA[6]P
set_property PACKAGE_PIN P23 [get_ports {rx1_data_in_p[7]}];  #ADS42LB69:DA[7]P
set_property PACKAGE_PIN E17 [get_ports rx1_ovr_in];  #ADS42LB69:CTRL1

# RX2 pin assignments.
set_property PACKAGE_PIN T24 [get_ports {rx2_data_in_p[0]}];  #ADS42LB69:DB[0]P
set_property PACKAGE_PIN T22 [get_ports {rx2_data_in_p[1]}];  #ADS42LB69:DB[1]P
set_property PACKAGE_PIN T20 [get_ports {rx2_data_in_p[2]}];  #ADS42LB69:DB[2]P
set_property PACKAGE_PIN R26 [get_ports {rx2_data_in_p[3]}];  #ADS42LB69:DB[3]P
set_property PACKAGE_PIN R25 [get_ports {rx2_data_in_p[4]}];  #ADS42LB69:DB[4]P
set_property PACKAGE_PIN R22 [get_ports {rx2_data_in_p[5]}];  #ADS42LB69:DB[5]P
set_property PACKAGE_PIN R21 [get_ports {rx2_data_in_p[6]}];  #ADS42LB69:DB[6]P
set_property PACKAGE_PIN P24 [get_ports {rx2_data_in_p[7]}];  #ADS42LB69:DB[7]P
set_property PACKAGE_PIN F17 [get_ports rx2_ovr_in];  #ADS42LB69:CTRL2

# RX1/RX2 clock forward pin assignment.
set_property PACKAGE_PIN N26 [get_ports rx1to2_clk_in_p];  #ADS42LB69:CLKOUTP
